ActionKey class

A key that performs an action like space, return, or backspace.

Inheritance

Constructors

ActionKey(VirtualKeyboardKeyAction action)
Creates an ActionKey with the given action.

Properties

action VirtualKeyboardKeyAction?
The action this key performs, if it is an Action key.
finalinherited
capsText String?
The uppercase version of text, used for shift or caps lock.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
keyType VirtualKeyboardKeyType
The type of this key (action or string).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text this key represents.
getter/setter pairinherited
willExpand bool
Whether the key should expand to fill available horizontal space.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited