VirtualKeyboardKey class

A base class representing a key on the virtual keyboard.

Keys can be either text-producing or action-performing. This class is extended by TextKey and ActionKey.

Implementers

Constructors

VirtualKeyboardKey({String? text, String? capsText, required VirtualKeyboardKeyType keyType, VirtualKeyboardKeyAction? action})
Creates a virtual keyboard key with the specified keyType.

Properties

action VirtualKeyboardKeyAction?
The action this key performs, if it is an Action key.
final
capsText String?
The uppercase version of text, used for shift or caps lock.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyType VirtualKeyboardKeyType
The type of this key (action or string).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text this key represents.
getter/setter pair
willExpand bool
Whether the key should expand to fill available horizontal space.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited