VirtualKeyboardKeyAction enum

Represents the type of action a virtual keyboard key performs.

These actions are used by the virtual keyboard to handle non-character keys such as backspace, return, shift, etc.

Inheritance
Available extensions

Values

Backspace → const VirtualKeyboardKeyAction

Deletes the character before the cursor.

Return → const VirtualKeyboardKeyAction

Inserts a new line character (\n).

Shift → const VirtualKeyboardKeyAction

Toggles between lowercase and uppercase characters.

Space → const VirtualKeyboardKeyAction

Inserts a space character.

Symbols → const VirtualKeyboardKeyAction

Switches to the symbols keyboard layout.

Alpha → const VirtualKeyboardKeyAction

Switches to the alphanumeric keyboard layout.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VirtualKeyboardKeyAction>
A constant List of the values in this enum, in order of their declaration.