virtual_keyboard_plus library
Classes
- ActionKey
- A key that performs an action like space, return, or backspace.
- TextKey
- A key that inserts a character into the input field.
- VirtualKeyboard
- A custom virtual keyboard widget for Flutter.
- VirtualKeyboardKey
- A base class representing a key on the virtual keyboard.
Enums
- VirtualKeyboardKeyAction
- Represents the type of action a virtual keyboard key performs.
- VirtualKeyboardKeyType
- Represents the type of a virtual keyboard key.
- VirtualKeyboardType
- Represents the different types of virtual keyboard layouts.
Properties
-
dualLayout
↔ List<
List< VirtualKeyboardKey> > -
A combined layout for both alphanumeric and symbolic keys.
getter/setter pair
-
numericLayout
↔ List<
List< VirtualKeyboardKey> > -
A layout for the numeric keyboard.
getter/setter pair
-
symbolLayout
↔ List<
List< VirtualKeyboardKey> > -
A layout for the symbol keyboard.
getter/setter pair
-
usLayout
↔ List<
List< VirtualKeyboardKey> > -
A layout for the standard US QWERTY keyboard.
getter/setter pair