VirtualKeyboardType enum
Represents the different types of virtual keyboard layouts.
These layouts determine the set of keys available on the keyboard.
- Numeric: A keyboard layout with numeric keys (0-9).
- Alphanumeric: A standard alphanumeric layout with letters and numbers.
- Symbolic: A keyboard layout for symbols and special characters.
- Dual: A keyboard layout that combines both alphanumeric and symbolic keys.
Values
- Numeric → const VirtualKeyboardType
-
A keyboard layout with numeric keys (0-9).
- Alphanumeric → const VirtualKeyboardType
-
A keyboard layout with both letters (A-Z) and numbers (0-9).
- Symbolic → const VirtualKeyboardType
-
A keyboard layout with special symbols (e.g., punctuation, currency symbols).
- Dual → const VirtualKeyboardType
-
A keyboard layout that combines both alphanumeric and symbolic keys.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VirtualKeyboardType> - A constant List of the values in this enum, in order of their declaration.